---
title: Welcome to AIGVE!
template: home.html
---

<!-- # Welcome to AIGVE: the AI Generated Video Evaluation toolkit! -->

<!-- For full documentation visit [mkdocs.org](https://www.mkdocs.org).

## Commands

* `mkdocs new [dir-name]` - Create a new project.
* `mkdocs serve` - Start the live-reloading docs server.
* `mkdocs build` - Build the documentation site.
* `mkdocs -h` - Print help message and exit.

## Project layout

    mkdocs.yml    # The configuration file.
    docs/
        index.md  # The documentation homepage.
        ...       # Other markdown pages, images and other files.
        ...       # Other markdown pages, images and other files. -->


<!-- ---
hide:
  - navigation
  - toc
--- -->

<!-- # ![AIGVE Logo](assets/img/aigve_logo.png){ align=center width=200 } -->





